@@ -20,16 +20,10 @@ from pathlib import Path
 from typing import Iterable
 
 import click
-import requests
 from apd.authentication import get_auth_headers
 from LbAPCommon import parse_yaml, render_yaml, validate_yaml
-from LbAPCommon.checks import run_job_checks
-from LbAPCommon.checks_utils import checks_to_JSON, hist_to_root
 from pkg_resources import DistributionNotFound, get_distribution
 
-from .checks import checks_exist, perform_checks
-from .log_parsing import show_log_advice
-from .testing import enter_debugging, prepare_reproduce, prepare_test
 from .utils import (
     LBAPI_HOST,
     available_productions,
@@ -74,6 +68,8 @@ def main():
 @main.command()
 def login():
     """Login to the Analysis Productions API"""
+    import requests
+
     r = requests.get(f"{LBAPI_HOST}/user", **get_auth_headers())
     r.raise_for_status()
     click.secho(f"Logged in successfully as {r.json()['username']}", fg="green")
@@ -86,7 +82,8 @@ def login():
 )
 def versions(working_group: str, production_name: production_name_type) -> None:
     """List the available tags of the Analysis Productions repository by running 'lb-ap versions' \n
-    List the available tags for a specific production by running 'lb-ap versions <WORKING_GROUP> <YOUR_PRODUCTION>'"""
+    List the available tags for a specific production by running 'lb-ap versions <WORKING_GROUP> <YOUR_PRODUCTION>'
+    """
     # TODO the comments below are to facilitate mapping each version to a production but requires some changes
     # in the api website at a later date
     if not production_name:
@@ -187,7 +184,8 @@ def checkout(
     allow_deletes: bool,
 ) -> None:
     """Clean out the current copy of the specified production and clone the production from the specified version \n
-    List the available tags for a specific production by running 'lb-ap versions <YOUR_PRODUCTION>'"""
+    List the available tags for a specific production by running 'lb-ap versions <YOUR_PRODUCTION>'
+    """
     _checkout(
         working_group,
         production_name,
@@ -263,7 +261,8 @@ def _run_git(
 @click.argument("production_name", type=production_name_type, default="", nargs=1)
 def list(production_name):
     """List the available production folders by running 'lb-ap list' \n
-    List the available productions for a specific production by running 'lb-ap list <YOUR_PRODUCTION>'"""
+    List the available productions for a specific production by running 'lb-ap list <YOUR_PRODUCTION>'
+    """
     inside_ap_datapkg()
 
     if production_name:
@@ -288,7 +287,8 @@ def list(production_name):
 @click.argument("job_name", type=str, default="", nargs=1)
 def list_checks(production_name, job_name):
     """List the checks for a specific production by running lb-ap list-checks <YOUR_PRODUCTION> \n
-    List only the checks required by a specific job by running lb-ap list-checks <YOUR_PRODUCTION> <YOUR_JOB>"""
+    List only the checks required by a specific job by running lb-ap list-checks <YOUR_PRODUCTION> <YOUR_JOB>
+    """
     inside_ap_datapkg()
 
     # Check if production exists
@@ -358,7 +358,7 @@ def render(production_name):
         click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
         raise click.ClickException("Failed to parse and validate YAML")
     else:
-        for warning in warnings:
+        for warning in warnings or []:
             click.secho(f"WARNING: {warning}", fg="yellow")
         click.secho("YAML parsed and validated successfully", fg="green")
 
@@ -392,7 +392,7 @@ def validate(production_name):
         click.secho("Error validating YAML!", fg="red")
         raise click.ClickException(str(e))
     else:
-        for warning in warnings:
+        for warning in warnings or []:
             click.secho(f"WARNING: {warning}", fg="yellow")
         click.secho("YAML validated successfully", fg="green")
 
@@ -410,9 +410,17 @@ def validate(production_name):
 )
 def test(production_name, job_name, dependent_input, validate):
     """Execute a job locally"""
+    inside_ap_datapkg()
+
+    # Check if production exists
+    check_production(production_name)
+
+    # validate test environment
     if validate:
         validate_environment()
-    inside_ap_datapkg()
+
+    from .log_parsing import show_log_advice
+    from .testing import prepare_test
 
     out_dir, prodrun_config_path = prepare_test(
         production_name, job_name, dependent_input
@@ -475,8 +483,8 @@ def test(production_name, job_name, dependent_input, validate):
     #         job_name,
     #         prod_data,
     #     )
-    warnings.extend(yaml_warnings)
-    for warning in warnings:
+    warnings.extend(yaml_warnings or [])
+    for warning in warnings or []:
         click.secho(f"WARNING: {warning}", fg="yellow")
 
     if errors:
@@ -491,6 +499,8 @@ def test(production_name, job_name, dependent_input, validate):
             fg="green",
         )
 
+    from .checks import checks_exist, perform_checks
+
     # Run checks
     if checks_exist(checks_data):
         checks_output_dir = join(out_dir, "checks")
@@ -524,7 +534,7 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir, valida
         click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
         raise click.ClickException("Failed to parse and validate YAML")
     else:
-        for warning in warnings:
+        for warning in warnings or []:
             click.secho(f"WARNING: {warning}", fg="yellow")
         click.secho("YAML parsed and validated successfully", fg="green")
 
@@ -532,6 +542,8 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir, valida
     if not checks_output_dir:
         checks_output_dir = join(os.path.dirname(test_ntuple_path), "checks")
 
+    from .checks import checks_exist, perform_checks
+
     # Run checks
     if checks_exist(checks_data):
         perform_checks(production_name, job_name, [test_ntuple_path], checks_output_dir)
@@ -546,6 +558,9 @@ def ci_checks(
     checks_data_file: str, input_ntuple: str, output_dir: str, job_index: int
 ):
     """Helper function for running checks in the CI. This is not recommended for users."""
+
+    from .checks import run_job_checks
+
     click.secho("Starting checks!", fg="green")
     with open(checks_data_file, "r") as inf:
         test_info = json.load(inf)
@@ -554,6 +569,9 @@ def ci_checks(
         test_info["jobs"][job_index]["checks_data"],
         [input_ntuple],
     )
+
+    from LbAPCommon.checks_utils import checks_to_JSON, hist_to_root
+
     hist_to_root(
         test_info["jobs"][job_index]["name"], check_results, f"{output_dir}/checks.root"
     )
@@ -579,9 +597,12 @@ def ci_checks(
 )
 def debug(production_name, job_name, dependent_input, validate):
     """Start an interactive session inside the job's environment"""
+    inside_ap_datapkg()
+    check_production(production_name)
     if validate:
         validate_environment()
-    inside_ap_datapkg()
+
+    from .testing import enter_debugging, prepare_test
 
     enter_debugging(*prepare_test(production_name, job_name, dependent_input))
 
@@ -596,6 +617,9 @@ def reproduce(pipeline_id, production_name, job_name, test_id, validate):
     """Reproduce an existing online test locally"""
     if validate:
         validate_environment()
+
+    from .testing import enter_debugging, prepare_reproduce
+
     enter_debugging(*prepare_reproduce(pipeline_id, production_name, job_name, test_id))
 
 
@@ -610,6 +634,9 @@ def reproduce(pipeline_id, production_name, job_name, test_id, validate):
 )
 def parse_log(log_fn, suppress):
     """Read a Gaudi log file and extract information"""
+
+    from .log_parsing import show_log_advice
+
     with open(log_fn, "rt") as fp:
         log_text = fp.read()
 
