@@ -21,12 +21,12 @@ from os.path import join
 
 import click
 import requests
-from LbAPCommon import get_api_token, parse_yaml, render_yaml, validate_yaml
+from apd.authentication import get_auth_headers
+from LbAPCommon import parse_yaml, render_yaml, validate_yaml
 from LbAPCommon.hacks import project_uses_cmt
 from LbAPCommon.options_parsing import validate_options
 
 from .utils import (
-    LBAPI_CLIENT_ID,
     LBAPI_HOST,
     check_production,
     check_status_code,
@@ -39,8 +39,6 @@ from .utils import (
 
 def prepare_test(production_name, job_name, dependent_input=None):
     """Run a local test job for a specific production job"""
-    token = get_api_token(LBAPI_CLIENT_ID, f"{LBAPI_HOST}/user")
-
     # Check if production exists
     check_production(production_name)
 
@@ -57,15 +55,21 @@ def prepare_test(production_name, job_name, dependent_input=None):
         )
 
     application_name, application_version = job_data["application"].rsplit("/", 1)
+    application = {
+        "name": application_name,
+        "version": application_version,
+        "data_pkgs": ["AnalysisProductions v999999999999"],
+    }
+    if "@" in application_version:
+        app_version, binary_tag = application_version.split("@", 1)
+        application["version"] = app_version
+        application["binary_tag"] = binary_tag
+
     require_cmt = project_uses_cmt(application_name, application_version)
 
     prodrun_conf = {
         "spec_version": 1,
-        "application": {
-            "name": application_name,
-            "version": application_version,
-            "data_pkgs": ["AnalysisProductions v999999999999"],
-        },
+        "application": application,
         "input": {"xml_summary_file": "summaryDaVinci_00012345_00006789_1.xml"},
         "output": {"prefix": "00012345_00006789_1"},
     }
@@ -99,7 +103,7 @@ def prepare_test(production_name, job_name, dependent_input=None):
             params["override-output-filetype"] = output_filetype
         response = requests.post(
             f"{LBAPI_HOST}/pipelines/autoconf-options/",
-            headers={"Authorization": f"Bearer {token}"},
+            **get_auth_headers(),
             json={**job_data, **({"input": override_input} if override_input else {})},
             params=params,
         )
@@ -128,7 +132,7 @@ def prepare_test(production_name, job_name, dependent_input=None):
         else:
             response = requests.post(
                 f"{LBAPI_HOST}/pipelines/lfns/",
-                headers={"Authorization": f"Bearer {token}"},
+                **get_auth_headers(),
                 json=job_data["input"],
             )
             lfns = check_status_code(response).json()
@@ -145,21 +149,19 @@ def prepare_test(production_name, job_name, dependent_input=None):
 
 
 def prepare_reproduce(pipeline_id, production_name, job_name, test_id):
-    token = get_api_token(LBAPI_CLIENT_ID, f"{LBAPI_HOST}/user")
-
     click.secho(
         f"Reproducing test for test {pipeline_id} {production_name} {job_name}",
         fg="green",
     )
 
     prod_url = f"{LBAPI_HOST}/pipelines/{pipeline_id}/{production_name}/"
-    response = requests.get(prod_url, headers={"Authorization": f"Bearer {token}"})
+    response = requests.get(prod_url, **get_auth_headers())
     prod_info = check_status_code(response).json()
 
     job_url = f"{prod_url}jobs/{job_name}/"
     if test_id != "latest":
         job_url += f"tests/{test_id}"
-    response = requests.get(job_url, headers={"Authorization": f"Bearer {token}"})
+    response = requests.get(job_url, **get_auth_headers())
     job_info = check_status_code(response).json()
     if test_id == "latest":
         job_url += f"tests/{job_info['test']['attempt']}"
@@ -183,9 +185,7 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id):
     dynamic_dir, out_dir = create_output_dir(production_name, require_cmt)
 
     # Download the jobs output sandbox
-    response = requests.get(
-        f"{job_url}/zip", headers={"Authorization": f"Bearer {token}"}
-    )
+    response = requests.get(f"{job_url}/zip", **get_auth_headers())
     zip_data = io.BytesIO(check_status_code(response).content)
     with zipfile.ZipFile(zip_data) as zf:
         zf.extractall(out_dir)
@@ -217,7 +217,7 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id):
         response = requests.get(
             f"{prod_url}jobs/{job_info['input']['job_name']}/tests/"
             f"{job_info['test']['attempt']}/files/{filename.name}/url",
-            headers={"Authorization": f"Bearer {token}"},
+            **get_auth_headers(),
         )
         url = check_status_code(response).json()["url"]
 
