@@ -25,6 +25,10 @@ from LbAPCommon.hacks import setup_lbrun_environment
 
 LBAPI_HOST = os.environ.get("LBAPI_HOST", "https://lbap.app.cern.ch")
 
+RE_PRODUCTION_NAME = re.compile(
+    r"^(?:[a-z][a-z0-9_]+/)*[a-z][a-z0-9_]+/?$", re.IGNORECASE
+)
+
 
 def validate_environment():
     click.secho("Validating environment", fg="green")
@@ -100,6 +104,11 @@ def check_production(production_name):
         raise click.ClickException(
             f"Can't find production {production_name}. Does it have an info.yaml?"
         )
+    if not RE_PRODUCTION_NAME.match(production_name):
+        raise click.ClickException(
+            f"Production name must match the pattern {RE_PRODUCTION_NAME.pattern!r}. "
+            "Please choose a different name."
+        )
 
 
 def check_production_existed(available_versions: dict, production_name: str):
