@@ -38,11 +38,11 @@ versions_output = [
 
 args_clone_https = [
     "clone",
-    "v0r0p2180615",
     "B2OC",
     "B02DKPi",
+    "v0r0p2180615",
     "aiwieder/test_checkout",
-    "https",
+    "--clone-type=https",
 ]
 args_checkout = ["checkout"]
 
